import { ModernExtend, Range, DefinitionOta } from './types';
import { KeyValue, Configure } from './types';
declare const reportingConfigTimeLookup: {
    '1_HOUR': number;
    MAX: number;
    '30_MINUTES': number;
    '10_SECONDS': number;
};
type ReportingConfigTime = number | keyof typeof reportingConfigTimeLookup;
type ReportingConfigAttribute = string | number | {
    ID: number;
    type: number;
};
type ReportingConfig = {
    min: ReportingConfigTime;
    max: ReportingConfigTime;
    change: number | [number, number];
    attribute: ReportingConfigAttribute;
};
export type ReportingConfigWithoutAttribute = Omit<ReportingConfig, 'attribute'>;
export declare function setupConfigureForReporting(cluster: string | number, attribute: ReportingConfigAttribute, endpointID?: number, config?: ReportingConfigWithoutAttribute): Configure;
export declare function identify(): ModernExtend;
export interface OnOffArgs {
    powerOnBehavior?: boolean;
    ota?: DefinitionOta;
    skipDuplicateTransaction?: boolean;
    endpoints?: {
        [s: string]: number;
    };
    configureReporting?: boolean;
}
export declare function onOff(args?: OnOffArgs): ModernExtend;
type MultiplierDivisor = {
    multiplier?: number;
    divisor?: number;
};
export interface ElectricityMeterArgs {
    cluster?: 'both' | 'metering' | 'electrical';
    current?: false | MultiplierDivisor;
    power?: false | MultiplierDivisor;
    voltage?: false | MultiplierDivisor;
    energy?: false | MultiplierDivisor;
}
export declare function electricityMeter(args?: ElectricityMeterArgs): ModernExtend;
export interface LightArgs {
    effect?: boolean;
    powerOnBehavior?: boolean;
    colorTemp?: {
        startup?: boolean;
        range: Range;
    };
    color?: boolean | {
        modes?: ('xy' | 'hs')[];
        applyRedFix?: boolean;
        enhancedHue?: boolean;
    };
    turnsOffAtBrightness1?: boolean;
    configureReporting?: boolean;
    endpoints?: {
        [s: string]: number;
    };
    ota?: DefinitionOta;
}
export declare function light(args?: LightArgs): ModernExtend;
export interface LockArgs {
    pinCodeCount: number;
}
export declare function lock(args?: LockArgs): ModernExtend;
export interface EnumLookupArgs {
    name: string;
    lookup: KeyValue;
    cluster: string | number;
    attribute: string | {
        ID: number;
        type: number;
    };
    description: string;
    zigbeeCommandOptions?: {
        manufacturerCode?: number;
        disableDefaultResponse?: boolean;
    };
    readOnly?: boolean;
    endpoint?: string;
    endpointID?: number;
    reporting?: ReportingConfigWithoutAttribute;
}
export declare function enumLookup(args: EnumLookupArgs): ModernExtend;
export interface NumericArgs {
    name: string;
    cluster: string | number;
    attribute: string | {
        ID: number;
        type: number;
    };
    description: string;
    zigbeeCommandOptions?: {
        manufacturerCode?: number;
        disableDefaultResponse?: boolean;
    };
    readOnly?: boolean;
    unit?: string;
    endpoint?: string;
    endpointID?: number;
    reporting?: ReportingConfigWithoutAttribute;
    valueMin?: number;
    valueMax?: number;
    valueStep?: number;
    scale?: number;
}
export declare function numeric(args: NumericArgs): ModernExtend;
export interface BinaryArgs {
    name: string;
    valueOn: [string | boolean, unknown];
    valueOff: [string | boolean, unknown];
    cluster: string | number;
    attribute: string | {
        ID: number;
        type: number;
    };
    description: string;
    zigbeeCommandOptions?: {
        manufacturerCode: number;
    };
    endpoint?: string;
    endpointID?: number;
    reporting?: ReportingConfig;
    readOnly?: boolean;
}
export declare function binary(args: BinaryArgs): ModernExtend;
export interface ActionEnumLookupArgs {
    lookup: KeyValue;
    cluster: string | number;
    attribute: string | {
        ID: number;
        type: number;
    };
    postfixWithEndpointName?: boolean;
}
export declare function actionEnumLookup(args: ActionEnumLookupArgs): ModernExtend;
export declare function forcePowerSource(args: {
    powerSource: 'Mains (single phase)' | 'Battery';
}): ModernExtend;
export declare function reconfigureReportingsOnDeviceAnnounce(): ModernExtend;
export declare function forceDeviceType(args: {
    type: 'EndDevice' | 'Router';
}): ModernExtend;
export declare function temperature(args?: Partial<NumericArgs>): ModernExtend;
export declare function humidity(args?: Partial<NumericArgs>): ModernExtend;
export declare function batteryPercentage(args?: Partial<NumericArgs>): ModernExtend;
export declare function pressure(args?: Partial<NumericArgs>): ModernExtend;
export {};
//# sourceMappingURL=modernExtend.d.ts.map